"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const endpoints = require("./endpoints");
const util_1 = require("./util");
async function getState(rawCookie) {
    const cookie = `.ROBLOSECURITY=${rawCookie};`;
    const req = await axios_1.default.get(endpoints.HOME, {
        headers: {
            Cookie: cookie
        },
        maxRedirects: 0,
        validateStatus: s => [200, 302].indexOf(s) >= 0
    });
    if (req.status !== 200) {
        throw new Error('Unable to log in with provided cookie');
    }
    const userId = util_1.extract(Number, req.data, /<meta name=user-data data-userid=(\d+)/, 'Unable to determine current user id');
    const csrfToken = util_1.extract(String, req.data, /Roblox.XsrfToken.setToken\('(.+)'\)/, 'Unable to extract CSRF token');
    return {
        headers: {
            Cookie: cookie,
            'X-CSRF-TOKEN': csrfToken
        },
        userId
    };
}
exports.default = getState;
//# sourceMappingURL=state.js.map